@@ -32,9 +32,6 @@
 
 namespace Algorithm
 {
-    template <typename ...>
-    using void_t = void;  // replace this with std::void_t in C++17
-
     template <typename T, typename = void>
     struct HasMappedType
         : std::false_type
@@ -42,19 +39,19 @@ namespace Algorithm
     };
 
     template <typename T>
-    struct HasMappedType<T, void_t<typename T::mapped_type>>
+    struct HasMappedType<T, std::void_t<typename T::mapped_type>>
         : std::true_type
     {
     };
 
-    // To be used with associative array types, such as QMap, QHash and it's variants
+    // To be used with associative array types, such as QMap, QHash and its variants
     template <typename T, typename BinaryPredicate
         , typename std::enable_if_t<HasMappedType<T>::value, int> = 0>
     void removeIf(T &dict, BinaryPredicate &&p)
     {
         auto it = dict.begin();
         while (it != dict.end())
-            it = (p(it.key(), it.value()) ? dict.erase(it) : (it + 1));
+            it = (p(it.key(), it.value()) ? dict.erase(it) : ++it);
     }
 
     // To be used with set types, such as QSet, std::set
@@ -64,6 +61,6 @@ namespace Algorithm
     {
         auto it = set.begin();
         while (it != set.end())
-            it = (p(*it) ? set.erase(it) : (it + 1));
+            it = (p(*it) ? set.erase(it) : ++it);
     }
 }
